# Projeto feito por Karina

Esse é um projeto da [digital innovation one](https://www.digitalinnovation.one)

# image_processing

Description. 
The package image_processing is used to:
	Processing:
		- Match histogram
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## pypi

https://pypi.org/project/image-processing-burato/

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image-processing-burato

```bash
pip install image-processing-burato
```

## Author
Karina

## License
[MIT](https://choosealicense.com/licenses/mit/)
